searchData={"items":[{"type":"module","title":"SrtParser","doc":"Documentation for `SrtParser`.\nIt provides a function to parse srt strings into a list of `ParsedSubtitle` structs.","ref":"SrtParser.html"},{"type":"function","title":"SrtParser.parse/1","doc":"Parse the given srt string into a tuple containing :ok and a list of `ParsedSubtitle` structs or a tuple with error and the error message. Start and end times are converted to milliseconds.","ref":"SrtParser.html#parse/1"},{"type":"function","title":"Example - SrtParser.parse/1","doc":"iex> SrtParser.parse(\"1\\n00:00:00,000 --> 00:00:02,123\\nHello world\\n\")\n  {:ok, [\n    %SrtParser.ParsedSubtitle{\n      id: 1,\n      start_time: 0,\n      end_time: 2123,\n      time_string: \"00:00:00,000 --> 00:00:02,123\",\n      text: \"Hello world\"\n    }\n  ]}","ref":"SrtParser.html#parse/1-example"},{"type":"function","title":"SrtParser.to_srt!/1","doc":"Get an SRT string from a list of `ParsedSubtitle` structs.","ref":"SrtParser.html#to_srt!/1"},{"type":"function","title":"Example - SrtParser.to_srt!/1","doc":"iex> SrtParser.to_srt!([%SrtParser.ParsedSubtitle{id: 1, start_time: 0, end_time: 2123, time_string: \"00:00:00,000 --> 00:00:02,123\", text: \"Hello world\"}])\n  \"1\\n00:00:00,000 --> 00:00:02,123\\nHello world\"","ref":"SrtParser.html#to_srt!/1-example"},{"type":"module","title":"SrtParser.ParsedSubtitle","doc":"","ref":"SrtParser.ParsedSubtitle.html"},{"type":"extras","title":"License","doc":"Copyright 2024 SAS Monocursive\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"},{"type":"extras","title":"Overview","doc":"# SrtParser\n\nElixir package to parse SRT (subtitles) files.\n\nThe goal was to be able to edit an SRT file from Elixir and save it back.\n\nThis library does not handle reading from a file, it only parses the content of a string.\n\n[View documentation](https://github.com/elixir-lang/ex_doc)","ref":"readme.html"},{"type":"extras","title":"Installation - Overview","doc":"If [available in Hex](https://hexdocs.pm/srt_parser), the package can be installed\nby adding `srt_parser` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:srt_parser, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Overview","doc":"Parse an SRT string:\n\n  ```elixir\n  iex> SrtParser.parse(\"1\\\\n00:00:00,000 --> 00:00:02,123\\\\nHello world\\\\n\")\n  {:ok, [\n    %SrtParser.ParsedSubtitle{\n      id: 1,\n      start_time: 0,\n      end_time: 2123,\n      time_string: \"00:00:00,000 --> 00:00:02,123\",\n      text: \"Hello world\"\n    }\n  ]}\n  ```\n  Get an SRT string from a list of ParsedSubtitle structs:\n\n  ```elixir\n  iex> SrtParser.to_srt!([%SrtParser.ParsedSubtitle{id: 1, start_time: 0, end_time: 2123, time_string: \"00:00:00,000 --> 00:00:02,123\", text: \"Hello world\"}])\n  \"1\\\\n00:00:00,000 --> 00:00:02,123\\\\nHello world\"\n  ```\n\n  Example on how to read an SRT file and parse it:\n\n  ```elixir\n  iex> File.read!(\"example.srt\") |> SrtParser.parse()\n  ```","ref":"readme.html#usage"},{"type":"extras","title":"Contributing - Overview","doc":"Feel free to send a pull request if you have any improvements to the library.\n\n  If you are considering to add a new feature, please create an issue first to discuss if the feature is a good fit for the project.\n\n  I want to keep it minimal and focused, but I know srt files can have a lot of different formats, so I'm open to adding new features.","ref":"readme.html#contributing"},{"type":"extras","title":"License - Overview","doc":"MIT","ref":"readme.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}